import feedparser
import time
import sqlite3
import pkg_resources
import pandas as pd
import json
from .feed import Feed
from .source_object import _Source

class Investing(_Source):

    def __init__(self, topics=[], save_feeds=True):
        """
        Object for maintaining Investing.com rss feeds.
        topics: a list of rss feed topics, must be one of the possible topics
            You can leave the list blank and call CNBC.get_possible_topics() and then add topics using CNBC.add_topics()
        save_feeds: Feed objects can save all previous news entries if this is True, otherwise the object will only the newest entries
        """
        super().__init__('Investing.com', save_feeds)
        self.add_topics(list(set(topics)))



from FinNews.feed import Feed
from FinNews.cnbc import CNBC
from FinNews.seeking_alpha import SeekingAlpha
from FinNews.investing import Investing
from FinNews.wsj import WSJ
from FinNews.yahoo import Yahoo

name = "FinNews"

__version__ = "0.8.1"

__all__ = ['Feed', 'CNBC', 'SeekingAlpha', 'Investing', 'WSJ', 'Yahoo']
